@@ -13,7 +13,7 @@ import matplotlib.pyplot as plt
 
 class ANN():
     
-    def __init__(self, input_shape, shape, output, activation= "sigmoid", loss = "auto", initializer = "auto", strict=False, delta=1e-7):
+    def __init__(self, input_shape, structure, output, activation= "sigmoid", loss = "auto", initializer = "auto", strict=False, delta=1e-7):
         
         #describes compatible parameters
     
@@ -28,7 +28,7 @@ class ANN():
         self.activations = []
         
         self.input_shape = input_shape
-        self.structure = shape
+        self.structure = structure
         self.strict = strict
         self.delta = delta
         self.initializer = None
@@ -69,7 +69,7 @@ class ANN():
                     
                 elif output == "identity":
                     self.loss = "mean_square"
-                    
+                
                 elif output == "relu":
                     self.loss = "mean_square"
 
@@ -86,27 +86,27 @@ class ANN():
         
         if activation == "relu":
             
-            for i in range(len(shape)-1):
+            for i in range(len(structure)-1):
                 self.activations.append("relu")
                 
         elif activation == "sigmoid":
             
-            for i in range(len(shape)-1):
+            for i in range(len(structure)-1):
                 self.activations.append("sigmoid")
                 
         elif activation == "softmax":
             
-            for i in range(len(shape)-1):
+            for i in range(len(structure)-1):
                 self.activations.append("softmax")
                 
         elif activation == "identity":
             
-            for i in range(len(shape)-1):
+            for i in range(len(structure)-1):
                 self.activations.append("identity")
                 
         elif type(activation) == list or type(activation) == tuple:
             
-            if len(activation) != len(shape)-1:
+            if len(activation) != len(structure)-1:
                 raise Exception("invalid number of activation functions")
             
             for i in range(len(activation)):
@@ -125,65 +125,65 @@ class ANN():
         
         if self.initializer == "uniform":
         
-            for i in range(len(shape)):
+            for i in range(len(structure)):
                 if i == 0:
-                    self.w_layers.append(np.random.rand(input_shape[1], shape[0]))
+                    self.w_layers.append(np.random.rand(input_shape[1], structure[0]))
                 else:
-                    self.w_layers.append(np.random.rand(shape[i-1], shape[i]))
+                    self.w_layers.append(np.random.rand(structure[i-1], structure[i]))
                 
-            for i in range(len(shape)):
-                #self.biases.append(np.random.rand(input_shape[0], shape[i]))
+            for i in range(len(structure)):
+                #self.biases.append(np.random.rand(input_shape[0], structure[i]))
                 self.b_layers.append(np.random.randn())
         
         elif self.initializer == "normal":
             
-            for i in range(len(shape)):
+            for i in range(len(structure)):
                 if i == 0:
-                    self.w_layers.append(np.random.randn(input_shape[1], shape[0]))
+                    self.w_layers.append(np.random.randn(input_shape[1], structure[0]))
                 else:
-                    self.w_layers.append(np.random.randn(shape[i-1], shape[i]))
+                    self.w_layers.append(np.random.randn(structure[i-1], structure[i]))
                 
-            for i in range(len(shape)):
-                #self.biases.append(np.random.randn(input_shape[0], shape[i]))
+            for i in range(len(structure)):
+                #self.biases.append(np.random.randn(input_shape[0], structure[i]))
                 self.b_layers.append(np.random.randn())
                 
         elif self.initializer == "xabier" or (self.initializer == "auto" and activation == "sigmoid"):
             
-            for i in range(len(shape)):
+            for i in range(len(structure)):
                 if i == 0:
-                    self.w_layers.append(np.random.randn(input_shape[1], shape[0]) / np.sqrt(input_shape[1]*shape[0]))
+                    self.w_layers.append(np.random.randn(input_shape[1], structure[0]) / np.sqrt(input_shape[1]*structure[0]))
                 else:
-                    self.w_layers.append(np.random.randn(shape[i-1], shape[i]) / np.sqrt(shape[i-1]*shape[i]))
+                    self.w_layers.append(np.random.randn(structure[i-1], structure[i]) / np.sqrt(structure[i-1]*structure[i]))
                 
-            for i in range(len(shape)):
-                #self.biases.append(np.random.randn(input_shape[0], shape[i]))
+            for i in range(len(structure)):
+                #self.biases.append(np.random.randn(input_shape[0], structure[i]))
                 self.b_layers.append(np.random.randn())
                 
             self.initializer = "xabier"
                
         elif self.initializer == "he" or (self.initializer == "auto" and activation == "relu"):
             
-            for i in range(len(shape)):
+            for i in range(len(structure)):
                 if i == 0:
-                    self.w_layers.append(np.random.randn(input_shape[1], shape[0]) / 2*np.sqrt(input_shape[1]*shape[0]))
+                    self.w_layers.append(np.random.randn(input_shape[1], structure[0]) / 2*np.sqrt(input_shape[1]*structure[0]))
                 else:
-                    self.w_layers.append(np.random.randn(shape[i-1], shape[i]) / 2*np.sqrt(shape[i-1]*shape[i]))
+                    self.w_layers.append(np.random.randn(structure[i-1], structure[i]) / 2*np.sqrt(structure[i-1]*structure[i]))
                 
-            for i in range(len(shape)):
-                #self.biases.append(np.random.randn(input_shape[0], shape[i]))
+            for i in range(len(structure)):
+                #self.biases.append(np.random.randn(input_shape[0], structure[i]))
                 self.b_layers.append(np.random.randn())
                 
             self.initializer = "he"
             
         else:
-            for i in range(len(shape)):
+            for i in range(len(structure)):
                 if i == 0:
-                    self.w_layers.append(np.random.randn(input_shape[1], shape[0]) / np.sqrt(input_shape[1]*shape[0]))
+                    self.w_layers.append(np.random.randn(input_shape[1], structure[0]) / np.sqrt(input_shape[1]*structure[0]))
                 else:
-                    self.w_layers.append(np.random.randn(shape[i-1], shape[i]) / np.sqrt(shape[i-1]*shape[i]))
+                    self.w_layers.append(np.random.randn(structure[i-1], structure[i]) / np.sqrt(structure[i-1]*structure[i]))
                 
-            for i in range(len(shape)):
-                #self.biases.append(np.random.randn(input_shape[0], shape[i]))
+            for i in range(len(structure)):
+                #self.biases.append(np.random.randn(input_shape[0], structure[i]))
                 self.b_layers.append(np.random.randn())
                 
             self.initializer = "xabier"
@@ -459,7 +459,7 @@ class ANN():
         return network_out
     
     
-    def train(self, x, t, learning_rate = 0.01, iteration = 100, save_log=False, flush_log=True, display=True, error_round=10):
+    def train(self, x, t, learning_rate, iteration, save_log=False, flush_log=True, display=True, error_round=10):
         
         print("mini batch process (learning rate: " + str(learning_rate) + ", iteration: " + str(iteration) + ")")
         
@@ -707,7 +707,7 @@ class ANN():
     
     #util: export
     
-    def export(self, directory, file_name="model.json"):
+    def export(self, directory=r".", file_name="model.json"):
         
         if not file_name.endswith(".json"):
             raise Exception("'file_name' must end with '.json'")
@@ -878,10 +878,11 @@ def make(file):
 
 def visualize_error_log(error_log):
 
-    #mpl.rc('xtick', color = '#4A4A4A', labelsize = 15)
-    #mpl.rc('ytick', color = '#4A4A4A', labelsize = 15)
-    #mpl.rc('lines', linewidth = 1.5, markeredgewidth = 0)
-    #mpl.rc('axes', labelsize= 20, titlesize = 30, titlepad=40, labelpad = 15)
+    mpl.rc('xtick', color = '#4A4A4A', labelsize = 12)
+    mpl.rc('ytick', color = '#4A4A4A', labelsize = 12)
+    mpl.rc('lines', linewidth = 1.5, markeredgewidth = 0)
+    mpl.rc('axes', labelsize= 18, titlesize = 30, titlepad=40, labelpad = 17)
+    mpl.rc('axes.spines', left=False, right=False, top=False, bottom = False)
 
     fig = plt.figure(figsize = (20, 10))
     plt.plot(error_log, color="#00ACCD")
